@@ -1,4 +1,4 @@
-# Copyright 2022 The LAST Authors.
+# Copyright 2023 The LAST Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,11 @@
 
 """LAST API."""
 
+from last import alignments
+from last import contexts
 from last import semirings
+from last import weight_fns
+from last.lattices import RecognitionLattice
 
 # A new PyPI release will be pushed everytime `__version__` is increased.
-__version__ = '0.0.1'
+__version__ = '0.0.2'
